<?PHP
/**
 * This file handles the insertion of new entries to a noda DB in batch.
 *
 * @file
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * This file handles the insertion of new entries to a noda DB in batch.
 */
final class NodaBatchInserter {
    /**
     * Inserts a batch of actor translations.
     *
     * @param MDMysqli                                                                                      $mysqli_noda DB connection.
     * @param array<array{persinst_id: int, lang: string, name: string, description: string, link: string}> $toInsert    List of actor translations to enter.
     *
     * @return void
     */
    public static function insertPersinstTranslations(MDMysqli $mysqli_noda, array $toInsert):void {

        $mysqli_noda->autocommit(false);
        $insertStmt = $mysqli_noda->do_prepare("CALL `nodaInsertPersinstTranslation`(?, ?, ?, ?, ?)");

        foreach ($toInsert as $values) {

            try {
                $insertStmt->bind_param("issss", $values['persinst_id'],
                    $values['lang'],
                    $values['name'],
                    $values['description'],
                    $values['link']);
                $insertStmt->execute();
            }
            catch (MDMysqliInvalidEncodingError $e) {
            }

        }

        $mysqli_noda->commit();
        $insertStmt->close();

        $mysqli_noda->autocommit(true);

    }

    /**
     * Inserts a batch of place translations.
     *
     * @param MDMysqli                                                                                 $mysqli_noda DB connection.
     * @param array<array{ort_id: int, lang: string, name: string, description: string, link: string}> $toInsert    List of place translations to enter.
     *
     * @return void
     */
    public static function insertPlaceTranslations(MDMysqli $mysqli_noda, array $toInsert):void {

        $mysqli_noda->autocommit(false);
        $insertStmt = $mysqli_noda->do_prepare("CALL `nodaInsertOrtTranslation`(?, ?, ?, ?, ?)");

        foreach ($toInsert as $values) {

            try {
                $insertStmt->bind_param("issss", $values['ort_id'],
                    $values['lang'],
                    $values['name'],
                    $values['description'],
                    $values['link']);
                $insertStmt->execute();
            }
            catch (MDMysqliInvalidEncodingError $e) {
            }

        }

        $mysqli_noda->commit();
        $insertStmt->close();

        $mysqli_noda->autocommit(true);

    }

    /**
     * Inserts a batch of tag translations.
     *
     * @param MDMysqli                                                                                 $mysqli_noda DB connection.
     * @param array<array{tag_id: int, lang: string, name: string, description: string, link: string}> $toInsert    List of tag translations to enter.
     *
     * @return void
     */
    public static function insertTagTranslations(MDMysqli $mysqli_noda, array $toInsert):void {

        $mysqli_noda->autocommit(false);
        $insertStmt = $mysqli_noda->do_prepare("CALL nodaInsertTagTranslation(?, ?, ?, ?, ?)");

        foreach ($toInsert as $values) {

            try {
                $insertStmt->bind_param("issss", $values['tag_id'],
                    $values['lang'],
                    $values['name'],
                    $values['description'],
                    $values['link']);
                $insertStmt->execute();
            }
            catch (MDMysqliInvalidEncodingError $e) {
            }

        }

        $mysqli_noda->commit();
        $insertStmt->close();

        $mysqli_noda->autocommit(true);

    }
}
